==> haskell-xml-conduit-1.4.0.3-1-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-xml-conduit.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: xml-conduit
version: 1.4.0.3
id: xml-conduit-1.4.0.3-1bd8KNJaq8DDj7hfPl9EFB
key: xml-conduit-1.4.0.3-1bd8KNJaq8DDj7hfPl9EFB
license: MIT
maintainer: Michael Snoyman <michael@snoyman.com>
stability: Stable
homepage: http://github.com/snoyberg/xml
synopsis: Pure-Haskell utilities for dealing with XML with the conduit package.
description:
    Hackage documentation generation is not reliable. For up to date documentation, please see: <http://www.stackage.org/package/xml-conduit>.
category: XML, Conduit
author: Michael Snoyman <michael@snoyman.com>, Aristid Breitkreuz <aristidb@googlemail.com>
exposed: True
exposed-modules:
    Text.XML.Stream.Parse Text.XML.Stream.Render Text.XML.Unresolved
    Text.XML.Cursor Text.XML.Cursor.Generic Text.XML
hidden-modules: Text.XML.Stream.Token
abi: 8e857f3b0bdee150549edb4d1c5cbed1
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/xml-conduit-1.4.0.3
library-dirs: /usr/lib/ghc-8.0.1/site-local/xml-conduit-1.4.0.3
data-dir: /usr/share/arm-linux-ghc-8.0.1/xml-conduit-1.4.0.3
hs-libraries: HSxml-conduit-1.4.0.3-1bd8KNJaq8DDj7hfPl9EFB
depends:
    attoparsec-0.13.1.0-IbZnQWsljer1cy7HS9Csat base-4.9.0.0
    blaze-builder-0.4.0.2-2VmGHau0mFrAjwd4n28WWF
    blaze-html-0.8.1.3-J9yr8vH3H9ALelvCpTjDjF
    blaze-markup-0.7.1.1-JmLydCOPoKfKgaFgoOctdP bytestring-0.10.8.1
    conduit-1.2.8-D9dRTYSavk8HJ0UStkfE43
    conduit-extra-1.1.15-824iGXaP3tL2Ph4TH8girc containers-0.5.7.1
    data-default-0.7.1.1-ZpKfkXGfJa8c8Q6OFbvrr deepseq-1.4.2.0
    monad-control-1.0.1.0-CVvkY5Vr2NNGCNJRXug3iR
    resourcet-1.1.9-J17FkGhZ2yV57Ehh8hruPC
    text-1.2.2.1-FgcR4Xf0VlEHD9HLxzq9WJ transformers-0.5.2.0
    xml-types-0.3.6-KjWhtX04gsiBko21cGwOxT
haddock-interfaces: /usr/share/doc/haskell-xml-conduit/html/xml-conduit.haddock
haddock-html: /usr/share/doc/haskell-xml-conduit/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-xml-conduit-1.4.0.3-2-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-xml-conduit.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: xml-conduit
version: 1.4.0.3
id: xml-conduit-1.4.0.3-B34HZuEPIgWJJINWrY8XWX
key: xml-conduit-1.4.0.3-B34HZuEPIgWJJINWrY8XWX
license: MIT
maintainer: Michael Snoyman <michael@snoyman.com>
stability: Stable
homepage: http://github.com/snoyberg/xml
synopsis: Pure-Haskell utilities for dealing with XML with the conduit package.
description:
    Hackage documentation generation is not reliable. For up to date documentation, please see: <http://www.stackage.org/package/xml-conduit>.
category: XML, Conduit
author: Michael Snoyman <michael@snoyman.com>, Aristid Breitkreuz <aristidb@googlemail.com>
exposed: True
exposed-modules:
    Text.XML.Stream.Parse Text.XML.Stream.Render Text.XML.Unresolved
    Text.XML.Cursor Text.XML.Cursor.Generic Text.XML
hidden-modules: Text.XML.Stream.Token
abi: 035763f14c0980421ef43e0b95340772
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/xml-conduit-1.4.0.3
library-dirs: /usr/lib/ghc-8.0.1/site-local/xml-conduit-1.4.0.3
data-dir: /usr/share/arm-linux-ghc-8.0.1/xml-conduit-1.4.0.3
hs-libraries: HSxml-conduit-1.4.0.3-B34HZuEPIgWJJINWrY8XWX
depends:
    attoparsec-0.13.1.0-6gEFbI8p8A3LThVdJgpVvH base-4.9.0.0
    blaze-builder-0.4.0.2-2VmGHau0mFrAjwd4n28WWF
    blaze-html-0.8.1.3-J9yr8vH3H9ALelvCpTjDjF
    blaze-markup-0.7.1.1-JmLydCOPoKfKgaFgoOctdP bytestring-0.10.8.1
    conduit-1.2.8-D9dRTYSavk8HJ0UStkfE43
    conduit-extra-1.1.15-1ZuWtV54hevB7dRz7GoUMb containers-0.5.7.1
    data-default-0.7.1.1-ZpKfkXGfJa8c8Q6OFbvrr deepseq-1.4.2.0
    monad-control-1.0.1.0-CVvkY5Vr2NNGCNJRXug3iR
    resourcet-1.1.9-J17FkGhZ2yV57Ehh8hruPC
    text-1.2.2.1-FgcR4Xf0VlEHD9HLxzq9WJ transformers-0.5.2.0
    xml-types-0.3.6-KjWhtX04gsiBko21cGwOxT
haddock-interfaces: /usr/share/doc/haskell-xml-conduit/html/xml-conduit.haddock
haddock-html: /usr/share/doc/haskell-xml-conduit/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
